function [ME_LHS,ME_RHS] = func_calc_MomentEqns117(Om,xVec,jVec,kVec,L,m,n)
% This function computes the Moment Equations (117) for a given
% input Omega vector, Om.  The output matrix ME_LHS contains 3 columns: x
% value, j value, LHS value for Eqn (117). ME_RHS contains three columns: x
% value, j value, RHS value for Eqn (117).

% Set up the first two columns of the ME_LHS and ME_LHS matrices
count = 0;
for II = 1:length(xVec)
    xVal = xVec(II);
    for JJ = 1:length(jVec)
        jVal = jVec(JJ);
        count = count + 1;
        ME_LHS(count,1:2) = [xVal,jVal];
        ME_RHS(count,1:2) = [xVal,jVal];
    end
end

% calculate the Gamma indexing matrix necessary for calculatig the RHS of
% Eqn (117), including the "backfilling" as defined in Eqn (56).
% Note there is a mistake in this equation which is fixed below.
[Gamma,junk] = func_Gamma_values(L,m);
clear junk
count = 0;
for XX = 1:length(xVec);
    xVal = xVec(XX);
    for JJ = 1:length(jVec)
        jVal = jVec(JJ);
        if ((xVal - jVal) >= (L-1))&(xVal<(L-1))       %Eqn (56) -> fixed in Zhang Eqn (10)
            count = count + 1;
            J_new = find(jVec == -jVal);
            X_new = find(xVec == (L-1));
            GammaIndex(count,1:3) = [xVal jVal ((-1)^m)*Gamma(J_new,X_new)];
            clear J_new X_new
        else
            count = count + 1;
            GammaIndex(count,1:3) = [xVal jVal Gamma(JJ,XX)];
        end
    end
end

% Calculate the LHS and RHS values for the given Om vector
for II = 1:length(xVec)
    xVal = xVec(II);
    for JJ = 1:length(jVec);
        jVal = jVec(JJ);
        temp_vec = 0;
        for KK = 1:length(kVec)     % Sum up the LHS for given j values
            kVal = kVec(KK);
            
            temp = find((Om(:,1) == xVal) & (Om(:,2) == jVal)&(Om(:,3) == kVal));
            if min(size(temp)) ~= 0
                temp_vec(KK,1) = kVal^n*Om(temp,end);
            else
                keyboard        % If this is triggered something is wrong
            end
            clear temp kVal
        end
        
        % Insert the sum of temp_vec into the appropriate spot in ME_LHS
        temp = find((ME_LHS(:,1) == xVal) & (ME_LHS(:,2) == jVal));
        if min(size(temp)) ~= 0
            ME_LHS(temp,3) = sum(temp_vec);
        else
            keyboard            % If this is triggered something is wrong
        end
        clear temp temp_vec
        
        % Insert the product of n!Gamma^m_j into the appropriate ME_RHS loc
        temp = find((ME_RHS(:,1) == xVal) & (ME_RHS(:,2) == jVal));
        if min(size(temp)) ~= 0
            ME_RHS(temp,3) = factorial(n)*GammaIndex(temp,3);
        else
            keyboard            % If this is triggered something is wrong
        end
        clear temp
        
        clear jVal temp_vec
    end
    clear xVal
end
