function [ME_LHS,ME_RHS] = func_calc_MomentEqns118(Om,xVec,jVec,kVec,L,m,n)
% This function computes the Moment Equations (118) for a given
% input Omega vector, Om.  The output matrix ME_LHS contains 3 columns: x
% value, j value, LHS value for Eqn (117). ME_RHS contains three columns: x
% value, j value, RHS value for Eqn (117).

% Set up the first two columns of the ME_LHS and ME_LHS matrices
count = 0;
for II = 1:length(xVec)
    xVal = xVec(II);
    for KK = 1:length(kVec)
        kVal = kVec(KK);
        count = count + 1;
        ME_LHS(count,1:2) = [xVal,kVal];
        ME_RHS(count,1:2) = [xVal,kVal];
    end
end

% calculate the Gamma indexing matrix necessary for calculatig the RHS of
% Eqn (118), including the "backfilling" as defined in Eqn (56).
% Note there is a mistake in this equation which is fixed below.
[Gamma,junk] = func_Gamma_values(L,n);
clear junk
count = 0;

for XX = 1:length(xVec);
    xVal = xVec(XX);
    for KK = 1:length(kVec)
        kVal = kVec(KK);
        if ((xVal - kVal) >= (L-1))&(xVal<(L-1))       %Eqn (56) -> fixed in Zhang Eqn (10)
            count = count + 1;
            K_new = find(kVec == -kVal);
            X_new = find(xVec == (L-1));
            GammaIndex(count,1:3) = [xVal kVal ((-1)^n)*Gamma(K_new,X_new)];
            clear K_new X_new
        else
            count = count + 1;
            GammaIndex(count,1:3) = [xVal kVal Gamma(KK,XX)];
        end
    end
end

% Calculate the LHS and RHS values for the given Om vector
for II = 1:length(xVec)
    xVal = xVec(II);
    for KK = 1:length(kVec);
        kVal = kVec(KK);
        temp_vec = 0;
        for JJ = 1:length(jVec)     % Sum up the LHS for given k values
            jVal = jVec(JJ);
            
            temp = find((Om(:,1) == xVal) & (Om(:,2) == jVal)&(Om(:,3) == kVal));
            if min(size(temp)) ~= 0
                temp_vec(JJ,1) = jVal^m*Om(temp,end);
            else
                keyboard        % If this is triggered something is wrong
            end
            clear temp jVal
        end
        
        % Insert the sum of temp_vec into the appropriate spot in ME_LHS
        temp = find((ME_LHS(:,1) == xVal) & (ME_LHS(:,2) == kVal));
        if min(size(temp)) ~= 0
            ME_LHS(temp,3) = sum(temp_vec);
        else
            keyboard            % If this is triggered something is wrong
        end
        clear temp temp_vec
        
        % Insert the product of m!Gamma^n_k into the appropriate ME_RHS loc
        temp = find((ME_RHS(:,1) == xVal) & (ME_RHS(:,2) == kVal));
        if min(size(temp)) ~= 0
            ME_RHS(temp,3) = factorial(m)*GammaIndex(temp,3);
        else
            keyboard            % If this is triggered something is wrong
        end
        clear temp
        
        clear kVal temp_vec
    end
    clear xVal
end
