function [admis_index] = func_calc_admissible_index(L,jVec,kVec)
% This function compiles a "connectivity matrix" of admissible index
% coefficients according to Eqns (110), (111) in Chen et al.  
% This is done in two steps for x=(L-1) values and x=1,2,...,(L-2) values
% because the conditions change.

% The matrix has 3 columns: [xValue jValue kValue]

%-------------------------------------------------
% Admissible j and k index values for x = (L-1)
count = 0;
admis_index_L1 = zeros(1,3);
for JJ = 1:length(jVec);
    for KK = 1:length(kVec);
        jVal = jVec(JJ);
        kVal = kVec(KK);
        
        if abs(jVal-kVal) < (L-1)       % from Eqn (110)
            count = count + 1;
            admis_index_L1(count,:) = [(L-1),jVal,kVal];
        end
        clear jVal kVal
    end
end
clear JJ KK jVal kVal

%-------------------------------------------------
% Admissible j and k index values for x = 1,2,...,(L-2)
count = 0;
admis_index_L2 = zeros(1,3);
for X = 1:(L-2)
    JJ_vec = ((X-L+2):(X-1))';          % from Eqn (111)
    KK_vec = ((X-L+2):(X-1))';
    
    for JJ = 1:length(JJ_vec);
        for KK = 1:length(KK_vec);
            jVal = JJ_vec(JJ);
            kVal = KK_vec(KK);
            
            if abs(jVal-kVal) < (L-1)   % from Eqn (110)
                count = count + 1;
                admis_index_L2(count,:) = [X,jVal,kVal];
            end
            clear jVal kVal
        end
    end
    clear JJ_vec KK_vec JJ KK jVal kVal
end

%-------------------------------------------------
% Concatinate the two sets of admissible indexing together
admis_index = [admis_index_L2;admis_index_L1];
