function [S_Mat]=func_calc_scaling_equations(admis_index,L,p)
% This function compiles this Scaling Equation matrix S from Eqn (113) in
% Chen et al.  All x values (x = 1,2,...,(L-1)) are included so the matrix
% order is ((L-2)^3 + (3L^2-9L+7)).

% The four quadrants of the matrix are: upper left is for x=1,2,...,(L-2),
% upper right is how x=1,2,...,{L-2) depends on x = (L-1),
% lower left is all zeros since x = (L-1) is independent of other x values,
% lower right is the x = (L-1) scaling equations


tot_unknown = size(admis_index,1);
S_Mat = zeros(tot_unknown,tot_unknown);

ia_vec = (0:(L-1))';
ib_vec = (0:(L-1))';
ic_vec = (0:(L-1))';

for II = 1:tot_unknown
    xVal = admis_index(II,1);
    jVal = admis_index(II,2);
    kVal = admis_index(II,3);
    
    for IIA = 1:length(ia_vec)
        ia = ia_vec(IIA);
        for IIB = 1:length(ib_vec)
            ib = ib_vec(IIB);
            for IIC = 1:length(ic_vec)
                ic = ic_vec(IIC);
                
                % determine the Omega indexes for the RHS of Eqn (113)
                jIndex = 2*jVal + ib - ia;
                kIndex = 2*kVal + ic - ia;
                xIndex = 2*xVal - ia;
                
                % this is the "backfill" condition in Eqn (112) which
                % requires updating the xVal for some x,j,k combinations
                if (xIndex >= (L-1))|((xIndex-jIndex)>=(L-1))|((xIndex-kIndex)>=(L-1))
                    xIndex = (L-1);
                end
                
                % find the row in the admissible index matrix which
                % corresponds to the x,j,k indexes. The appropriate row and
                % column of the S_Mat matrix is then increased by the
                % triple product of the filter coefficients as in Eqn (113)
                temp = find((admis_index(:,1) == xIndex) & (admis_index(:,2) == jIndex)&(admis_index(:,3) == kIndex));
                if min(size(temp)) ~= 0
                    S_Mat(II,temp) = S_Mat(II,temp) + p(ia+1)*p(ib+1)*p(ic+1);
                end
                clear ic jIndex kIndex xIndex temp
            end
        end
    end
    clear xVal jVal kVal
end
clear II IIA IIB IIC JJ X ia_vec ib_vec ic_vec ia ib ic temp